@@ -1,7 +1,12 @@
 import os
 
-app_path = r"d:/FastCNN/"
-data_path = r"e:/FastCNN/"
+def getRoot(sec=[r"C:/"]):
+    for r in sec:
+        if os.path.exists(r):
+            return r
+
+app_path = r"{}FastCNN/Coach".format(getRoot([r"d:/","c:/"]))
+data_path = r"{}FastCNN/Data".format(getRoot([r"e:/",r"d:/","c:/"]))
 
 class PathProxy:
     """
