@@ -333,19 +333,28 @@ class SelectModel:
                     # Write results
                     
                     for *xyxy, conf, cls in reversed(det):
-                        xyxy[0] /= sizex
-                        xyxy[1] /= sizey
-                        xyxy[2] /= sizex
-                        xyxy[3] /= sizey
                         
-                        xyxy[2] -= xyxy[0]
-                        xyxy[3] -= xyxy[1]
-                        for ritem in [cls,conf,*xyxy]:
+                        #xyxy[0] /= sizex
+                        #xyxy[1] /= sizey
+                        #xyxy[2] /= sizex
+                        #xyxy[3] /= sizey
+                        
+                        #xyxy[2] -= xyxy[0]
+                        #xyxy[3] -= xyxy[1]
+                        
+                        xywh = (xyxy2xywh(torch.tensor(xyxy).view(1, 4)) / gn).view(-1).tolist()
+                        xywh[0] -= xywh[2]/2
+                        xywh[1] -= xywh[3]/2
+                        for ritem in [cls,conf]:
                             if len(rtn['results']) > 0:
                                 rtn['results'] += ","
                             
-                            
                             rtn['results'] += str(round(ritem.item(),2))
+                        for cor in xywh:
+                            if len(rtn['results']) > 0:
+                                rtn['results'] += ","
+                            
+                            rtn['results'] += str(round(cor,2))
                         
             rtn["spend"] = dt[0]+dt[1]+dt[2]
                     
@@ -358,5 +367,5 @@ if __name__ == "__main__":
     #main(opt)
     _model.loadModel("New_Project2","20220602_031608")
     for i in range(5):
-        print(_model.predictSingle(r"E:\迅雷下载\val2017\val2017\000000001296.jpg"))
+        print(_model.predictSingle(r"D:\PSolution\yolov5\data\images\Error1_1_6312802_084623.bmp"))
     
